@@ -3,17 +3,20 @@ from deepcrawl.exceptions import InvalidContentType
 
 # Generate request headers with the API connection token and the appropriate content-type
 def get_request_headers(token="", content_type='json'):
-    if content_type == 'json':
-        content_type_value = 'application/json'
-    elif content_type == 'form':
-        content_type_value = 'application/x-www-form-urlencoded'
-    else:
-        raise InvalidContentType
-
-    return {
+    headers = {
         'X-Auth-Token': token,
-        'Content-Type': content_type_value,
         'Accept': '*/*',
         'Cache-Control': 'no-cache',
         'Accept-Encoding': 'gzip, deflate'
     }
+
+    if content_type == 'json':
+        headers.update({"Content-Type": 'application/json'})
+    elif content_type == 'form':
+        headers.update({"Content-Type": 'application/x-www-form-urlencoded'})
+    elif not content_type:
+        pass
+    else:
+        raise InvalidContentType
+
+    return headers
