@@ -240,3 +240,19 @@ class ProjectSettings(ImmutableAttributesMixin):
         self.is_meridian = project_settings.get('is_meridian')
 
         super(ProjectSettings, self).__init__()
+
+    @property
+    def to_dict_mutable_fields(self):
+        """
+        :return: dictionary with the mutable fields
+        :rtype: dict
+        """
+        return {x: getattr(self, x, None) for x in settings_mutable_fields}
+
+    @property
+    def to_dict_immutable_fields(self):
+        """
+        :return: dictionary with the immutable fields
+        :rtype: dict
+        """
+        return {x: getattr(self, x, None) for x in settings_immutable_fields}
