@@ -18,19 +18,19 @@ project_extra_fields = (
     "crawls",
     "issues",
     "schedules",
+    "custom_extractions"
 )
 
-project_mutable_fields = project_extra_fields + (
+project_mutable_fields = project_extra_fields
+
+project_immutable_fields = (
     "crawls_count",
     "issues_count",
     "next_run_time",
     "crawls_finished_last_finished_at",
     "crawls_finished_last_progress_crawled",
-    "custom_extractions"
-)
-
-project_immutable_fields = (
-
+    "_crawls_last_href",
+    "_crawls_finished_last_href",
 )
 
 project_fields = project_mutable_fields + project_immutable_fields + project_extra_fields
@@ -62,6 +62,8 @@ class DeepCrawlProject(ImmutableAttributesMixin):
             project_data.get('crawls_finished_last_finished_at')
         )
         self.crawls_finished_last_progress_crawled = project_data.get('crawls_finished_last_progress_crawled')
+        self._crawls_last_href = project_data.get('_crawls_last_href')
+        self._crawls_finished_last_href = project_data.get('_crawls_finished_last_href')
 
         # project settings
         self.project_settings = ProjectSettings(project_data)
@@ -241,7 +243,7 @@ class DeepCrawlProject(ImmutableAttributesMixin):
         """
         connection = connection or deepcrawl.DeepCrawlConnection.get_instance()
         project = connection.get_project(self.account_id, self.id)
-        for key in self.__slots__:
+        for key in self.mutable_attributes:
             setattr(self, key, getattr(project, key))
         return self
 
